@@ -1,22 +1,18 @@
-# -*- coding: utf-8 -*-
-
 """
 Univariate/multivariate cubic smoothing spline implementation
-
 """
 
+from typing import List, Optional, Tuple, Union
 import functools
-from typing import Optional, Union, Tuple, List
 
 import numpy as np
-
+from scipy.interpolate import PPoly
 import scipy.sparse as sp
 import scipy.sparse.linalg as la
-from scipy.interpolate import PPoly
 
-from ._base import ISplinePPForm, ISmoothingSpline
-from ._types import UnivariateDataType, MultivariateDataType
-from ._reshape import to_2d, prod
+from ._base import ISmoothingSpline, ISplinePPForm
+from ._reshape import prod, to_2d
+from ._types import MultivariateDataType, UnivariateDataType
 
 
 class SplinePPForm(ISplinePPForm[np.ndarray, int], PPoly):
@@ -61,9 +57,8 @@ class SplinePPForm(ISplinePPForm[np.ndarray, int], PPoly):
         return prod(shape)
 
     @property
-    def shape(self) -> Tuple[int]:
-        """Returns the source data shape
-        """
+    def shape(self) -> Tuple[int, ...]:
+        """Returns the source data shape"""
         shape: List[int] = list(self.c.shape[2:])
         shape.insert(self.axis, self.c.shape[1] + 1)
 
@@ -82,13 +77,7 @@ class SplinePPForm(ISplinePPForm[np.ndarray, int], PPoly):
         )
 
 
-class CubicSmoothingSpline(ISmoothingSpline[
-                               SplinePPForm,
-                               float,
-                               UnivariateDataType,
-                               int,
-                               Union[bool, str]
-                           ]):
+class CubicSmoothingSpline(ISmoothingSpline[SplinePPForm, float, UnivariateDataType, int, Union[bool, str]]):
     """Cubic smoothing spline
 
     The cubic spline implementation for univariate/multivariate data.
@@ -125,14 +114,15 @@ class CubicSmoothingSpline(ISmoothingSpline[
 
     __module__ = 'csaps'
 
-    def __init__(self,
-                 xdata: UnivariateDataType,
-                 ydata: MultivariateDataType,
-                 weights: Optional[UnivariateDataType] = None,
-                 smooth: Optional[float] = None,
-                 axis: int = -1,
-                 normalizedsmooth: bool = False):
-
+    def __init__(
+        self,
+        xdata: UnivariateDataType,
+        ydata: MultivariateDataType,
+        weights: Optional[UnivariateDataType] = None,
+        smooth: Optional[float] = None,
+        axis: int = -1,
+        normalizedsmooth: bool = False,
+    ):
         x, y, w, shape, axis = self._prepare_data(xdata, ydata, weights, axis)
         coeffs, smooth = self._make_spline(x, y, w, smooth, shape, normalizedsmooth)
         spline = SplinePPForm.construct_fast(coeffs, x, axis=axis)
@@ -140,10 +130,12 @@ class CubicSmoothingSpline(ISmoothingSpline[
         self._smooth = smooth
         self._spline = spline
 
-    def __call__(self,
-                 x: UnivariateDataType,
-                 nu: Optional[int] = None,
-                 extrapolate: Optional[Union[bool, str]] = None) -> np.ndarray:
+    def __call__(
+        self,
+        x: UnivariateDataType,
+        nu: Optional[int] = None,
+        extrapolate: Optional[Union[bool, str]] = None,
+    ) -> np.ndarray:
         """Evaluate the spline for given data
 
         Parameters
@@ -211,7 +203,8 @@ class CubicSmoothingSpline(ISmoothingSpline[
         if ydata.shape[axis] != xdata.size:
             raise ValueError(
                 f"'ydata' data must be a 1-D or N-D array with shape[{axis}] "
-                f"that is equal to 'xdata' size ({xdata.size})")
+                f"that is equal to 'xdata' size ({xdata.size})"
+            )
 
         # Rolling axis for using its shape while constructing coeffs array
         shape = np.rollaxis(ydata, axis).shape
@@ -241,7 +234,7 @@ class CubicSmoothingSpline(ISmoothingSpline[
         def trace(m: sp.dia_matrix):
             return m.diagonal().sum()
 
-        return 1. / (1. + trace(a) / (6. * trace(b)))
+        return 1.0 / (1.0 + trace(a) / (6.0 * trace(b)))
 
     @staticmethod
     def _normalize_smooth(x: np.ndarray, w: np.ndarray, smooth: Optional[float]):
@@ -251,9 +244,9 @@ class CubicSmoothingSpline(ISmoothingSpline[
 
         span = np.ptp(x)
 
-        eff_x = 1 + (span ** 2) / np.sum(np.diff(x) ** 2)
-        eff_w = np.sum(w) ** 2 / np.sum(w ** 2)
-        k = 80 * (span ** 3) * (x.size ** -2) * (eff_x ** -0.5) * (eff_w ** -0.5)
+        eff_x = 1 + (span**2) / np.sum(np.diff(x) ** 2)
+        eff_w = np.sum(w) ** 2 / np.sum(w**2)
+        k = 80 * (span**3) * (x.size**-2) * (eff_x**-0.5) * (eff_w**-0.5)
 
         s = 0.5 if smooth is None else smooth
         p = s / (s + (1 - s) * k)
@@ -266,8 +259,7 @@ class CubicSmoothingSpline(ISmoothingSpline[
         dx = np.diff(x)
 
         if not all(dx > 0):  # pragma: no cover
-            raise ValueError(
-                "Items of 'xdata' vector must satisfy the condition: x1 < x2 < ... < xN")
+            raise ValueError("Items of 'xdata' vector must satisfy the condition: x1 < x2 < ... < xN")
 
         dy = np.diff(y, axis=1)
         dy_dx = dy / dx
@@ -287,12 +279,11 @@ class CubicSmoothingSpline(ISmoothingSpline[
         diags_r = np.vstack((dx[1:], 2 * (dx[1:] + dx[:-1]), dx[:-1]))
         r = sp.spdiags(diags_r, [-1, 0, 1], pcount - 2, pcount - 2)
 
-        dx_recip = 1. / dx
+        dx_recip = 1.0 / dx
         diags_qtw = np.vstack((dx_recip[:-1], -(dx_recip[1:] + dx_recip[:-1]), dx_recip[1:]))
-        diags_sqrw_recip = 1. / np.sqrt(w)
+        diags_sqrw_recip = 1.0 / np.sqrt(w)
 
-        qtw = (sp.diags(diags_qtw, [0, 1, 2], (pcount - 2, pcount)) @
-               sp.diags(diags_sqrw_recip, 0, (pcount, pcount)))
+        qtw = sp.diags(diags_qtw, [0, 1, 2], (pcount - 2, pcount)) @ sp.diags(diags_sqrw_recip, 0, (pcount, pcount))
         qtw = qtw @ qtw.T
 
         p = smooth
@@ -302,7 +293,7 @@ class CubicSmoothingSpline(ISmoothingSpline[
         elif smooth is None:
             p = CubicSmoothingSpline._compute_smooth(r, qtw)
 
-        pp = (6. * (1. - p))
+        pp = 6.0 * (1.0 - p)
 
         # Solve linear system for the 2nd derivatives
         a = pp * qtw + p * r
@@ -321,15 +312,15 @@ class CubicSmoothingSpline(ISmoothingSpline[
         d1 = np.diff(vpad(u), axis=0) / dx
         d2 = np.diff(vpad(d1), axis=0)
 
-        diags_w_recip = 1. / w
+        diags_w_recip = 1.0 / w
         w = sp.diags(diags_w_recip, 0, (pcount, pcount))
 
         yi = y.T - (pp * w) @ d2
         pu = vpad(p * u)
 
         c1 = np.diff(pu, axis=0) / dx
-        c2 = 3. * pu[:-1, :]
-        c3 = np.diff(yi, axis=0) / dx - dx * (2. * pu[:-1, :] + pu[1:, :])
+        c2 = 3.0 * pu[:-1, :]
+        c3 = np.diff(yi, axis=0) / dx - dx * (2.0 * pu[:-1, :] + pu[1:, :])
         c4 = yi[:-1, :]
 
         c_shape = (4, pcount - 1) + shape[1:]
